==============================================
Welcome to Basket Client Documentation!
==============================================

This documentation explains how to install and use the Basket Client.


About The Basket Client
-----------------------

This is a client for Mozilla's email subscription service,
basket. Basket is not a real subscription service, but it talks to a
real one and we don't really care who/what it is.


Contents
--------

.. toctree::
   :maxdepth: 1

   install
   usage
   change_log
